# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import collibra_core
from collibra_core.models.change_complex_relation_type_request import ChangeComplexRelationTypeRequest  # noqa: E501
from collibra_core.rest import ApiException

class TestChangeComplexRelationTypeRequest(unittest.TestCase):
    """ChangeComplexRelationTypeRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ChangeComplexRelationTypeRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = collibra_core.models.change_complex_relation_type_request.ChangeComplexRelationTypeRequest()  # noqa: E501
        if include_optional :
            return ChangeComplexRelationTypeRequest(
                name = '0', 
                description = '0', 
                color = 'a', 
                symbol_type = 'NONE', 
                icon_code = '0', 
                acronym_code = 'a', 
                attribute_types = [
                    collibra_core.models.complex_relation_attribute_type_request.ComplexRelationAttributeTypeRequest(
                        min = 0, 
                        max = 2, 
                        attribute_type_id = '0', 
                        id = '0', )
                    ], 
                leg_types = [
                    collibra_core.models.complex_relation_leg_type_request.ComplexRelationLegTypeRequest(
                        min = 1, 
                        max = 3, 
                        role = '0', 
                        co_role = '0', 
                        asset_type_id = '0', 
                        id = '0', 
                        relation_type_id = '0', )
                    ]
            )
        else :
            return ChangeComplexRelationTypeRequest(
        )

    def testChangeComplexRelationTypeRequest(self):
        """Test ChangeComplexRelationTypeRequest"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import collibra_core
from collibra_core.api.tags_api import TagsApi  # noqa: E501
from collibra_core.rest import ApiException


class TestTagsApi(unittest.TestCase):
    """TagsApi unit test stubs"""

    def setUp(self):
        self.api = collibra_core.api.tags_api.TagsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_change_tag(self):
        """Test case for change_tag

        Change tag.  # noqa: E501
        """
        pass

    def test_exists(self):
        """Test case for exists

        Check tag name.  # noqa: E501
        """
        pass

    def test_find_tags(self):
        """Test case for find_tags

        Find tags.  # noqa: E501
        """
        pass

    def test_get_tag(self):
        """Test case for get_tag

        Get tag.  # noqa: E501
        """
        pass

    def test_get_tags_by_asset_id(self):
        """Test case for get_tags_by_asset_id

        Get asset tags.  # noqa: E501
        """
        pass

    def test_merge_tags(self):
        """Test case for merge_tags

        Merge tags.  # noqa: E501
        """
        pass

    def test_remove_tag(self):
        """Test case for remove_tag

        Remove tag.  # noqa: E501
        """
        pass

    def test_remove_tags(self):
        """Test case for remove_tags

        Remove tags.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from collibra_core.api_client import ApiClient
from collibra_core.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class DiagramPicturesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_diagram_picture(self, **kwargs):  # noqa: E501
        """Adds a diagram picture.  # noqa: E501

        Take a diagram picture for a given asset and diagram view. A diagram picture is a copy of traceability diagram (result diagram) at a given time (for more information on traceability diagram check DGC User Guide).  The motivation behind diagram picture is to be able to reopen them at a later point in time and be able to see them them exactly as they were created. This feature is not possible for result diagram which are always showing the current situation.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_diagram_picture(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddDiagramPictureRequest add_diagram_picture_request:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.add_diagram_picture_with_http_info(**kwargs)  # noqa: E501

    def add_diagram_picture_with_http_info(self, **kwargs):  # noqa: E501
        """Adds a diagram picture.  # noqa: E501

        Take a diagram picture for a given asset and diagram view. A diagram picture is a copy of traceability diagram (result diagram) at a given time (for more information on traceability diagram check DGC User Guide).  The motivation behind diagram picture is to be able to reopen them at a later point in time and be able to see them them exactly as they were created. This feature is not possible for result diagram which are always showing the current situation.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_diagram_picture_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddDiagramPictureRequest add_diagram_picture_request:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(str, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'add_diagram_picture_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_diagram_picture" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_diagram_picture_request' in local_var_params:
            body_params = local_var_params['add_diagram_picture_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/diagramPictures', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from collibra_core.configuration import Configuration


class User(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'created_by': 'str',
        'created_on': 'int',
        'last_modified_by': 'str',
        'last_modified_on': 'int',
        'system': 'bool',
        'resource_type': 'str',
        'user_name': 'str',
        'first_name': 'str',
        'last_name': 'str',
        'email_address': 'str',
        'gender': 'str',
        'language': 'str',
        'additional_email_addresses': 'list[Email]',
        'phone_numbers': 'list[PhoneNumber]',
        'instant_messaging_accounts': 'list[InstantMessagingAccount]',
        'websites': 'list[Website]',
        'addresses': 'list[Address]',
        'activated': 'bool',
        'enabled': 'bool',
        'ldap_user': 'bool',
        'user_source': 'str',
        'guest_user': 'bool',
        'api_user': 'bool',
        'license_type': 'str'
    }

    attribute_map = {
        'id': 'id',
        'created_by': 'createdBy',
        'created_on': 'createdOn',
        'last_modified_by': 'lastModifiedBy',
        'last_modified_on': 'lastModifiedOn',
        'system': 'system',
        'resource_type': 'resourceType',
        'user_name': 'userName',
        'first_name': 'firstName',
        'last_name': 'lastName',
        'email_address': 'emailAddress',
        'gender': 'gender',
        'language': 'language',
        'additional_email_addresses': 'additionalEmailAddresses',
        'phone_numbers': 'phoneNumbers',
        'instant_messaging_accounts': 'instantMessagingAccounts',
        'websites': 'websites',
        'addresses': 'addresses',
        'activated': 'activated',
        'enabled': 'enabled',
        'ldap_user': 'ldapUser',
        'user_source': 'userSource',
        'guest_user': 'guestUser',
        'api_user': 'apiUser',
        'license_type': 'licenseType'
    }

    def __init__(self, id=None, created_by=None, created_on=None, last_modified_by=None, last_modified_on=None, system=None, resource_type=None, user_name=None, first_name=None, last_name=None, email_address=None, gender=None, language=None, additional_email_addresses=None, phone_numbers=None, instant_messaging_accounts=None, websites=None, addresses=None, activated=None, enabled=None, ldap_user=None, user_source=None, guest_user=None, api_user=None, license_type=None, local_vars_configuration=None):  # noqa: E501
        """User - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._created_by = None
        self._created_on = None
        self._last_modified_by = None
        self._last_modified_on = None
        self._system = None
        self._resource_type = None
        self._user_name = None
        self._first_name = None
        self._last_name = None
        self._email_address = None
        self._gender = None
        self._language = None
        self._additional_email_addresses = None
        self._phone_numbers = None
        self._instant_messaging_accounts = None
        self._websites = None
        self._addresses = None
        self._activated = None
        self._enabled = None
        self._ldap_user = None
        self._user_source = None
        self._guest_user = None
        self._api_user = None
        self._license_type = None
        self.discriminator = None

        self.id = id
        if created_by is not None:
            self.created_by = created_by
        if created_on is not None:
            self.created_on = created_on
        if last_modified_by is not None:
            self.last_modified_by = last_modified_by
        if last_modified_on is not None:
            self.last_modified_on = last_modified_on
        if system is not None:
            self.system = system
        self.resource_type = resource_type
        if user_name is not None:
            self.user_name = user_name
        if first_name is not None:
            self.first_name = first_name
        if last_name is not None:
            self.last_name = last_name
        if email_address is not None:
            self.email_address = email_address
        if gender is not None:
            self.gender = gender
        if language is not None:
            self.language = language
        if additional_email_addresses is not None:
            self.additional_email_addresses = additional_email_addresses
        if phone_numbers is not None:
            self.phone_numbers = phone_numbers
        if instant_messaging_accounts is not None:
            self.instant_messaging_accounts = instant_messaging_accounts
        if websites is not None:
            self.websites = websites
        if addresses is not None:
            self.addresses = addresses
        if activated is not None:
            self.activated = activated
        if enabled is not None:
            self.enabled = enabled
        if ldap_user is not None:
            self.ldap_user = ldap_user
        if user_source is not None:
            self.user_source = user_source
        if guest_user is not None:
            self.guest_user = guest_user
        if api_user is not None:
            self.api_user = api_user
        if license_type is not None:
            self.license_type = license_type

    @property
    def id(self):
        """Gets the id of this User.  # noqa: E501

        The id of the represented object (entity).  # noqa: E501

        :return: The id of this User.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this User.

        The id of the represented object (entity).  # noqa: E501

        :param id: The id of this User.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def created_by(self):
        """Gets the created_by of this User.  # noqa: E501

        The id of the user that created this resource.  # noqa: E501

        :return: The created_by of this User.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this User.

        The id of the user that created this resource.  # noqa: E501

        :param created_by: The created_by of this User.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def created_on(self):
        """Gets the created_on of this User.  # noqa: E501

        The timestamp (in UTC time standard) of the creation of this resource.  # noqa: E501

        :return: The created_on of this User.  # noqa: E501
        :rtype: int
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this User.

        The timestamp (in UTC time standard) of the creation of this resource.  # noqa: E501

        :param created_on: The created_on of this User.  # noqa: E501
        :type: int
        """

        self._created_on = created_on

    @property
    def last_modified_by(self):
        """Gets the last_modified_by of this User.  # noqa: E501

        The id of the user who modified this resource the last time.  # noqa: E501

        :return: The last_modified_by of this User.  # noqa: E501
        :rtype: str
        """
        return self._last_modified_by

    @last_modified_by.setter
    def last_modified_by(self, last_modified_by):
        """Sets the last_modified_by of this User.

        The id of the user who modified this resource the last time.  # noqa: E501

        :param last_modified_by: The last_modified_by of this User.  # noqa: E501
        :type: str
        """

        self._last_modified_by = last_modified_by

    @property
    def last_modified_on(self):
        """Gets the last_modified_on of this User.  # noqa: E501

        The timestamp (in UTC time standard) of the last modification of this resource.  # noqa: E501

        :return: The last_modified_on of this User.  # noqa: E501
        :rtype: int
        """
        return self._last_modified_on

    @last_modified_on.setter
    def last_modified_on(self, last_modified_on):
        """Sets the last_modified_on of this User.

        The timestamp (in UTC time standard) of the last modification of this resource.  # noqa: E501

        :param last_modified_on: The last_modified_on of this User.  # noqa: E501
        :type: int
        """

        self._last_modified_on = last_modified_on

    @property
    def system(self):
        """Gets the system of this User.  # noqa: E501

        Whether this is a system resource or not.  # noqa: E501

        :return: The system of this User.  # noqa: E501
        :rtype: bool
        """
        return self._system

    @system.setter
    def system(self, system):
        """Sets the system of this User.

        Whether this is a system resource or not.  # noqa: E501

        :param system: The system of this User.  # noqa: E501
        :type: bool
        """

        self._system = system

    @property
    def resource_type(self):
        """Gets the resource_type of this User.  # noqa: E501

        The type of this resource, i.e. [Community, Asset, Domain, Attribute, Relation, WorkflowInstance].  # noqa: E501

        :return: The resource_type of this User.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """Sets the resource_type of this User.

        The type of this resource, i.e. [Community, Asset, Domain, Attribute, Relation, WorkflowInstance].  # noqa: E501

        :param resource_type: The resource_type of this User.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and resource_type is None:  # noqa: E501
            raise ValueError("Invalid value for `resource_type`, must not be `None`")  # noqa: E501
        allowed_values = ["View", "Asset", "Community", "Domain", "AssetType", "DomainType", "Status", "User", "ClassificationMatch", "UserGroup", "Attribute", "StringAttribute", "ScriptAttribute", "BooleanAttribute", "DateAttribute", "NumericAttribute", "SingleValueListAttribute", "MultiValueListAttribute", "Comment", "Attachment", "Responsibility", "Workflow", "Job", "Relation", "RelationType", "ComplexRelation", "ComplexRelationType", "ArticulationRule", "Assignment", "Scope", "RelationTrace", "ValidationRule", "DataQualityRule", "DataQualityMetric", "Address", "InstantMessagingAccount", "Email", "PhoneNumber", "Website", "Activity", "FormProperty", "WorkflowTask", "ActivityChange", "WorkflowInstance", "Role", "AttributeType", "BooleanAttributeType", "DateAttributeType", "DateTimeAttributeType", "MultiValueListAttributeType", "NumericAttributeType", "ScriptAttributeType", "SingleValueListAttributeType", "StringAttributeType", "ViewSharingRule", "ViewAssignmentRule", "JdbcDriverFile", "JdbcDriver", "JdbcIngestionProperties", "CsvIngestionProperties", "ExcelIngestionProperties", "ConnectionStringParameter", "AssignedCharacteristicType", "Notification", "Tag", "ComplexRelationLegType", "ComplexRelationAttributeType", "ComplexRelationLeg", "BaseDataType", "AdvancedDataType", "DiagramPicture", "DiagramPictureSharingRule", "DiagramPictureAssignmentRule", "Rating", "Classification", "PhysicalDataConnector", "Context"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and resource_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `resource_type` ({0}), must be one of {1}"  # noqa: E501
                .format(resource_type, allowed_values)
            )

        self._resource_type = resource_type

    @property
    def user_name(self):
        """Gets the user_name of this User.  # noqa: E501

        The user name.  # noqa: E501

        :return: The user_name of this User.  # noqa: E501
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """Sets the user_name of this User.

        The user name.  # noqa: E501

        :param user_name: The user_name of this User.  # noqa: E501
        :type: str
        """

        self._user_name = user_name

    @property
    def first_name(self):
        """Gets the first_name of this User.  # noqa: E501

        The first name of the user.  # noqa: E501

        :return: The first_name of this User.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this User.

        The first name of the user.  # noqa: E501

        :param first_name: The first_name of this User.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this User.  # noqa: E501

        The last name of the user.  # noqa: E501

        :return: The last_name of this User.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this User.

        The last name of the user.  # noqa: E501

        :param last_name: The last_name of this User.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    @property
    def email_address(self):
        """Gets the email_address of this User.  # noqa: E501

        The main email address.  # noqa: E501

        :return: The email_address of this User.  # noqa: E501
        :rtype: str
        """
        return self._email_address

    @email_address.setter
    def email_address(self, email_address):
        """Sets the email_address of this User.

        The main email address.  # noqa: E501

        :param email_address: The email_address of this User.  # noqa: E501
        :type: str
        """

        self._email_address = email_address

    @property
    def gender(self):
        """Gets the gender of this User.  # noqa: E501

        The gender of the user.  # noqa: E501

        :return: The gender of this User.  # noqa: E501
        :rtype: str
        """
        return self._gender

    @gender.setter
    def gender(self, gender):
        """Sets the gender of this User.

        The gender of the user.  # noqa: E501

        :param gender: The gender of this User.  # noqa: E501
        :type: str
        """
        allowed_values = ["MALE", "FEMALE", "UNKNOWN"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and gender not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `gender` ({0}), must be one of {1}"  # noqa: E501
                .format(gender, allowed_values)
            )

        self._gender = gender

    @property
    def language(self):
        """Gets the language of this User.  # noqa: E501

        The current language preference for this user.  # noqa: E501

        :return: The language of this User.  # noqa: E501
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this User.

        The current language preference for this user.  # noqa: E501

        :param language: The language of this User.  # noqa: E501
        :type: str
        """

        self._language = language

    @property
    def additional_email_addresses(self):
        """Gets the additional_email_addresses of this User.  # noqa: E501

        The list of additional email addresses.  # noqa: E501

        :return: The additional_email_addresses of this User.  # noqa: E501
        :rtype: list[Email]
        """
        return self._additional_email_addresses

    @additional_email_addresses.setter
    def additional_email_addresses(self, additional_email_addresses):
        """Sets the additional_email_addresses of this User.

        The list of additional email addresses.  # noqa: E501

        :param additional_email_addresses: The additional_email_addresses of this User.  # noqa: E501
        :type: list[Email]
        """

        self._additional_email_addresses = additional_email_addresses

    @property
    def phone_numbers(self):
        """Gets the phone_numbers of this User.  # noqa: E501

        The list of phone numbers.  # noqa: E501

        :return: The phone_numbers of this User.  # noqa: E501
        :rtype: list[PhoneNumber]
        """
        return self._phone_numbers

    @phone_numbers.setter
    def phone_numbers(self, phone_numbers):
        """Sets the phone_numbers of this User.

        The list of phone numbers.  # noqa: E501

        :param phone_numbers: The phone_numbers of this User.  # noqa: E501
        :type: list[PhoneNumber]
        """

        self._phone_numbers = phone_numbers

    @property
    def instant_messaging_accounts(self):
        """Gets the instant_messaging_accounts of this User.  # noqa: E501

        The list of instant messaging accounts.  # noqa: E501

        :return: The instant_messaging_accounts of this User.  # noqa: E501
        :rtype: list[InstantMessagingAccount]
        """
        return self._instant_messaging_accounts

    @instant_messaging_accounts.setter
    def instant_messaging_accounts(self, instant_messaging_accounts):
        """Sets the instant_messaging_accounts of this User.

        The list of instant messaging accounts.  # noqa: E501

        :param instant_messaging_accounts: The instant_messaging_accounts of this User.  # noqa: E501
        :type: list[InstantMessagingAccount]
        """

        self._instant_messaging_accounts = instant_messaging_accounts

    @property
    def websites(self):
        """Gets the websites of this User.  # noqa: E501

        The list of websites.  # noqa: E501

        :return: The websites of this User.  # noqa: E501
        :rtype: list[Website]
        """
        return self._websites

    @websites.setter
    def websites(self, websites):
        """Sets the websites of this User.

        The list of websites.  # noqa: E501

        :param websites: The websites of this User.  # noqa: E501
        :type: list[Website]
        """

        self._websites = websites

    @property
    def addresses(self):
        """Gets the addresses of this User.  # noqa: E501

        The list of addresses.  # noqa: E501

        :return: The addresses of this User.  # noqa: E501
        :rtype: list[Address]
        """
        return self._addresses

    @addresses.setter
    def addresses(self, addresses):
        """Sets the addresses of this User.

        The list of addresses.  # noqa: E501

        :param addresses: The addresses of this User.  # noqa: E501
        :type: list[Address]
        """

        self._addresses = addresses

    @property
    def activated(self):
        """Gets the activated of this User.  # noqa: E501

        Whether this user account is already activated or not.  # noqa: E501

        :return: The activated of this User.  # noqa: E501
        :rtype: bool
        """
        return self._activated

    @activated.setter
    def activated(self, activated):
        """Sets the activated of this User.

        Whether this user account is already activated or not.  # noqa: E501

        :param activated: The activated of this User.  # noqa: E501
        :type: bool
        """

        self._activated = activated

    @property
    def enabled(self):
        """Gets the enabled of this User.  # noqa: E501

        Whether this user account is already enabled or not.  # noqa: E501

        :return: The enabled of this User.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this User.

        Whether this user account is already enabled or not.  # noqa: E501

        :param enabled: The enabled of this User.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def ldap_user(self):
        """Gets the ldap_user of this User.  # noqa: E501

        Whether this is an LDAP user or not.  # noqa: E501

        :return: The ldap_user of this User.  # noqa: E501
        :rtype: bool
        """
        return self._ldap_user

    @ldap_user.setter
    def ldap_user(self, ldap_user):
        """Sets the ldap_user of this User.

        Whether this is an LDAP user or not.  # noqa: E501

        :param ldap_user: The ldap_user of this User.  # noqa: E501
        :type: bool
        """

        self._ldap_user = ldap_user

    @property
    def user_source(self):
        """Gets the user_source of this User.  # noqa: E501


        :return: The user_source of this User.  # noqa: E501
        :rtype: str
        """
        return self._user_source

    @user_source.setter
    def user_source(self, user_source):
        """Sets the user_source of this User.


        :param user_source: The user_source of this User.  # noqa: E501
        :type: str
        """
        allowed_values = ["INTERNAL", "LDAP", "SSO"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and user_source not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `user_source` ({0}), must be one of {1}"  # noqa: E501
                .format(user_source, allowed_values)
            )

        self._user_source = user_source

    @property
    def guest_user(self):
        """Gets the guest_user of this User.  # noqa: E501

        Whether this is a guest user or not.  # noqa: E501

        :return: The guest_user of this User.  # noqa: E501
        :rtype: bool
        """
        return self._guest_user

    @guest_user.setter
    def guest_user(self, guest_user):
        """Sets the guest_user of this User.

        Whether this is a guest user or not.  # noqa: E501

        :param guest_user: The guest_user of this User.  # noqa: E501
        :type: bool
        """

        self._guest_user = guest_user

    @property
    def api_user(self):
        """Gets the api_user of this User.  # noqa: E501

        Whether this is API user or not.  # noqa: E501

        :return: The api_user of this User.  # noqa: E501
        :rtype: bool
        """
        return self._api_user

    @api_user.setter
    def api_user(self, api_user):
        """Sets the api_user of this User.

        Whether this is API user or not.  # noqa: E501

        :param api_user: The api_user of this User.  # noqa: E501
        :type: bool
        """

        self._api_user = api_user

    @property
    def license_type(self):
        """Gets the license_type of this User.  # noqa: E501

        The licence type of the user.  # noqa: E501

        :return: The license_type of this User.  # noqa: E501
        :rtype: str
        """
        return self._license_type

    @license_type.setter
    def license_type(self, license_type):
        """Sets the license_type of this User.

        The licence type of the user.  # noqa: E501

        :param license_type: The license_type of this User.  # noqa: E501
        :type: str
        """
        allowed_values = ["CONSUMER", "AUTHOR"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and license_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `license_type` ({0}), must be one of {1}"  # noqa: E501
                .format(license_type, allowed_values)
            )

        self._license_type = license_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, User):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, User):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import collibra_core
from collibra_core.api.output_module_api import OutputModuleApi  # noqa: E501
from collibra_core.rest import ApiException


class TestOutputModuleApi(unittest.TestCase):
    """OutputModuleApi unit test stubs"""

    def setUp(self):
        self.api = collibra_core.api.output_module_api.OutputModuleApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_export_csv(self):
        """Test case for export_csv

        Exports results in CSV format, returns the results immediately.  # noqa: E501
        """
        pass

    def test_export_csv_in_job(self):
        """Test case for export_csv_in_job

        Exports results in CSV format, returns JSON representation of the async Job.  # noqa: E501
        """
        pass

    def test_export_csv_to_file(self):
        """Test case for export_csv_to_file

        Exports results in CSV format, returns information about created file.  # noqa: E501
        """
        pass

    def test_export_excel_in_job(self):
        """Test case for export_excel_in_job

        Exports results in Excel format, returns JSON representation of the async Job.  # noqa: E501
        """
        pass

    def test_export_excel_to_file(self):
        """Test case for export_excel_to_file

        Exports results in Excel format, returns information about created file.  # noqa: E501
        """
        pass

    def test_export_json(self):
        """Test case for export_json

        Exports results in JSON format, returns the results immediately.  # noqa: E501
        """
        pass

    def test_export_json_in_job(self):
        """Test case for export_json_in_job

        Exports results in JSON format, returns JSON representation of the async Job.  # noqa: E501
        """
        pass

    def test_export_json_to_file(self):
        """Test case for export_json_to_file

        Exports results in JSON format, returns information about created file.  # noqa: E501
        """
        pass

    def test_export_xml(self):
        """Test case for export_xml

        Exports results in XML format, returns the results immediately.  # noqa: E501
        """
        pass

    def test_export_xml_in_job(self):
        """Test case for export_xml_in_job

        Exports results in XML format, returns JSON representation of the async Job.  # noqa: E501
        """
        pass

    def test_export_xml_to_file(self):
        """Test case for export_xml_to_file

        Exports results in XML format, returns information about created file.  # noqa: E501
        """
        pass

    def test_get_table_view_config_by_view_id(self):
        """Test case for get_table_view_config_by_view_id

        Returns TableViewConfig based on id of given View and its Location.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import collibra_core
from collibra_core.models.set_asset_relations_request import SetAssetRelationsRequest  # noqa: E501
from collibra_core.rest import ApiException

class TestSetAssetRelationsRequest(unittest.TestCase):
    """SetAssetRelationsRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SetAssetRelationsRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = collibra_core.models.set_asset_relations_request.SetAssetRelationsRequest()  # noqa: E501
        if include_optional :
            return SetAssetRelationsRequest(
                type_id = '0', 
                related_asset_ids = [
                    '0'
                    ], 
                relation_direction = 'TO_TARGET'
            )
        else :
            return SetAssetRelationsRequest(
                type_id = '0',
                related_asset_ids = [
                    '0'
                    ],
                relation_direction = 'TO_TARGET',
        )

    def testSetAssetRelationsRequest(self):
        """Test SetAssetRelationsRequest"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from collibra_core.api_client import ApiClient
from collibra_core.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class AttachmentsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_attachment(self, **kwargs):  # noqa: E501
        """Add attachment  # noqa: E501

        Adds new attachment.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_attachment(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param file file: the file - attachment content
        :param str file_name: the display name of the file of this attachment
        :param str resource_type: the type of the resource the attachment should refer to. An attachment can be added on those resource types: User, Community, Domain, Asset, Role, ValidationRule, Workflow.
        :param str resource_id: the id of the resource the attachment should refer to
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AttachmentImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.add_attachment_with_http_info(**kwargs)  # noqa: E501

    def add_attachment_with_http_info(self, **kwargs):  # noqa: E501
        """Add attachment  # noqa: E501

        Adds new attachment.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_attachment_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param file file: the file - attachment content
        :param str file_name: the display name of the file of this attachment
        :param str resource_type: the type of the resource the attachment should refer to. An attachment can be added on those resource types: User, Community, Domain, Asset, Role, ValidationRule, Workflow.
        :param str resource_id: the id of the resource the attachment should refer to
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AttachmentImpl, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'file',
            'file_name',
            'resource_type',
            'resource_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_attachment" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'file' in local_var_params:
            local_var_files['file'] = local_var_params['file']  # noqa: E501
        if 'file_name' in local_var_params:
            form_params.append(('fileName', local_var_params['file_name']))  # noqa: E501
        if 'resource_type' in local_var_params:
            form_params.append(('resourceType', local_var_params['resource_type']))  # noqa: E501
        if 'resource_id' in local_var_params:
            form_params.append(('resourceId', local_var_params['resource_id']))  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/attachments', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AttachmentImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def find_attachments(self, **kwargs):  # noqa: E501
        """Find attachments  # noqa: E501

        Returns attachments matching the given search criteria. Only parameters that are specified in this request and have not <code>null</code> values are used for filtering. All other parameters are ignored. The returned attachments satisfy all constraints that are specified in this search criteria. By default a result containing 1000 attachments is returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_attachments(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used.
        :param int count_limit: Allows to limit the number of elements that will be counted. -1 will count everything and 0 will cause the count to be skipped
        :param str file_name: The name of the file representing searched attachment.
        :param str file_content_type: The type of the content of the file representing searched attachment.
        :param int upload_date: The date of attachment upload. It is the timestamp (in UTC time standard).
        :param str user_id: The ID of the user who uploaded the attachment.
        :param str base_resource_id: The ID of the resource the attachment refers to.
        :param str sort_field: The field that should be used as reference for sorting.
        :param str sort_order: The order of sorting.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AttachmentPagedResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.find_attachments_with_http_info(**kwargs)  # noqa: E501

    def find_attachments_with_http_info(self, **kwargs):  # noqa: E501
        """Find attachments  # noqa: E501

        Returns attachments matching the given search criteria. Only parameters that are specified in this request and have not <code>null</code> values are used for filtering. All other parameters are ignored. The returned attachments satisfy all constraints that are specified in this search criteria. By default a result containing 1000 attachments is returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.find_attachments_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int offset: The first result to retrieve. If not set (offset = <code>0</code>), results will be retrieved starting from row <code>0</code>.
        :param int limit: The maximum number of results to retrieve. If not set (limit = <code>0</code>), the default limit will be used.
        :param int count_limit: Allows to limit the number of elements that will be counted. -1 will count everything and 0 will cause the count to be skipped
        :param str file_name: The name of the file representing searched attachment.
        :param str file_content_type: The type of the content of the file representing searched attachment.
        :param int upload_date: The date of attachment upload. It is the timestamp (in UTC time standard).
        :param str user_id: The ID of the user who uploaded the attachment.
        :param str base_resource_id: The ID of the resource the attachment refers to.
        :param str sort_field: The field that should be used as reference for sorting.
        :param str sort_order: The order of sorting.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AttachmentPagedResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'offset',
            'limit',
            'count_limit',
            'file_name',
            'file_content_type',
            'upload_date',
            'user_id',
            'base_resource_id',
            'sort_field',
            'sort_order'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method find_attachments" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'offset' in local_var_params and local_var_params['offset'] is not None:  # noqa: E501
            query_params.append(('offset', local_var_params['offset']))  # noqa: E501
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'count_limit' in local_var_params and local_var_params['count_limit'] is not None:  # noqa: E501
            query_params.append(('countLimit', local_var_params['count_limit']))  # noqa: E501
        if 'file_name' in local_var_params and local_var_params['file_name'] is not None:  # noqa: E501
            query_params.append(('fileName', local_var_params['file_name']))  # noqa: E501
        if 'file_content_type' in local_var_params and local_var_params['file_content_type'] is not None:  # noqa: E501
            query_params.append(('fileContentType', local_var_params['file_content_type']))  # noqa: E501
        if 'upload_date' in local_var_params and local_var_params['upload_date'] is not None:  # noqa: E501
            query_params.append(('uploadDate', local_var_params['upload_date']))  # noqa: E501
        if 'user_id' in local_var_params and local_var_params['user_id'] is not None:  # noqa: E501
            query_params.append(('userId', local_var_params['user_id']))  # noqa: E501
        if 'base_resource_id' in local_var_params and local_var_params['base_resource_id'] is not None:  # noqa: E501
            query_params.append(('baseResourceId', local_var_params['base_resource_id']))  # noqa: E501
        if 'sort_field' in local_var_params and local_var_params['sort_field'] is not None:  # noqa: E501
            query_params.append(('sortField', local_var_params['sort_field']))  # noqa: E501
        if 'sort_order' in local_var_params and local_var_params['sort_order'] is not None:  # noqa: E501
            query_params.append(('sortOrder', local_var_params['sort_order']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/attachments', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AttachmentPagedResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_attachment(self, attachment_id, **kwargs):  # noqa: E501
        """Get attachment  # noqa: E501

        Returns information about the attachment identified by id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_attachment(attachment_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str attachment_id: the id of the attachment (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AttachmentImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_attachment_with_http_info(attachment_id, **kwargs)  # noqa: E501

    def get_attachment_with_http_info(self, attachment_id, **kwargs):  # noqa: E501
        """Get attachment  # noqa: E501

        Returns information about the attachment identified by id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_attachment_with_http_info(attachment_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str attachment_id: the id of the attachment (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AttachmentImpl, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'attachment_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_attachment" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'attachment_id' is set
        if self.api_client.client_side_validation and ('attachment_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['attachment_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `attachment_id` when calling `get_attachment`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'attachment_id' in local_var_params:
            path_params['attachmentId'] = local_var_params['attachment_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/attachments/{attachmentId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AttachmentImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_attachment_content(self, attachment_id, **kwargs):  # noqa: E501
        """Get attachment content  # noqa: E501

        Returns content of the attachment identified by given id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_attachment_content(attachment_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str attachment_id: the id of the attachment (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_attachment_content_with_http_info(attachment_id, **kwargs)  # noqa: E501

    def get_attachment_content_with_http_info(self, attachment_id, **kwargs):  # noqa: E501
        """Get attachment content  # noqa: E501

        Returns content of the attachment identified by given id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_attachment_content_with_http_info(attachment_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str attachment_id: the id of the attachment (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(file, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'attachment_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_attachment_content" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'attachment_id' is set
        if self.api_client.client_side_validation and ('attachment_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['attachment_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `attachment_id` when calling `get_attachment_content`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'attachment_id' in local_var_params:
            path_params['attachmentId'] = local_var_params['attachment_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/attachments/{attachmentId}/file', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='file',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_attachment(self, attachment_id, **kwargs):  # noqa: E501
        """Remove attachment  # noqa: E501

        Removes attachment identified by given id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_attachment(attachment_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str attachment_id: the id of the attachment (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.remove_attachment_with_http_info(attachment_id, **kwargs)  # noqa: E501

    def remove_attachment_with_http_info(self, attachment_id, **kwargs):  # noqa: E501
        """Remove attachment  # noqa: E501

        Removes attachment identified by given id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_attachment_with_http_info(attachment_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str attachment_id: the id of the attachment (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'attachment_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_attachment" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'attachment_id' is set
        if self.api_client.client_side_validation and ('attachment_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['attachment_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `attachment_id` when calling `remove_attachment`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'attachment_id' in local_var_params:
            path_params['attachmentId'] = local_var_params['attachment_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/attachments/{attachmentId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import collibra_core
from collibra_core.models.change_assignment_request import ChangeAssignmentRequest  # noqa: E501
from collibra_core.rest import ApiException

class TestChangeAssignmentRequest(unittest.TestCase):
    """ChangeAssignmentRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ChangeAssignmentRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = collibra_core.models.change_assignment_request.ChangeAssignmentRequest()  # noqa: E501
        if include_optional :
            return ChangeAssignmentRequest(
                status_ids = [
                    '0'
                    ], 
                characteristic_types = [
                    collibra_core.models.characteristic_type_assignment_reference.CharacteristicTypeAssignmentReference(
                        id = '0', 
                        min = 0, 
                        max = 56, 
                        type = 'View', 
                        relation_type_direction = 'TO_SOURCE', 
                        relation_type_restriction = '0', )
                    ], 
                articulation_rules = [
                    collibra_core.models.articulation_rule_request.ArticulationRuleRequest(
                        id = '0', 
                        operation = 'ADD', 
                        score = 1.337, 
                        status_id = '0', 
                        attribute_type_id = '0', )
                    ], 
                validation_rule_ids = [
                    '0'
                    ], 
                data_quality_rule_ids = [
                    '0'
                    ], 
                domain_type_ids = [
                    '0'
                    ], 
                default_status_id = '0', 
                scope_id = '0'
            )
        else :
            return ChangeAssignmentRequest(
        )

    def testChangeAssignmentRequest(self):
        """Test ChangeAssignmentRequest"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from collibra_core.api_client import ApiClient
from collibra_core.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class FilesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_files(self, **kwargs):  # noqa: E501
        """Upload files  # noqa: E501

        Upload files  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_files(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param file file: File to upload
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[FileInfoImpl]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.add_files_with_http_info(**kwargs)  # noqa: E501

    def add_files_with_http_info(self, **kwargs):  # noqa: E501
        """Upload files  # noqa: E501

        Upload files  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_files_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param file file: File to upload
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[FileInfoImpl], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'file'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_files" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'file' in local_var_params:
            local_var_files['file'] = local_var_params['file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/files', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[FileInfoImpl]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_file(self, file_id, **kwargs):  # noqa: E501
        """delete_file  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_file(file_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str file_id: the id of the file (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_file_with_http_info(file_id, **kwargs)  # noqa: E501

    def delete_file_with_http_info(self, file_id, **kwargs):  # noqa: E501
        """delete_file  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_file_with_http_info(file_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str file_id: the id of the file (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'file_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_file" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'file_id' is set
        if self.api_client.client_side_validation and ('file_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['file_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `file_id` when calling `delete_file`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'file_id' in local_var_params:
            path_params['fileId'] = local_var_params['file_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/files/{fileId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_file(self, file_id, **kwargs):  # noqa: E501
        """Download file  # noqa: E501

        Downloads file identified by given id.  Keep in mind to use GET /attachments/{attachmentId}/file instead of this endpoint when you want to get the file of an attachment.  A File and its id can be temporary so it's possible this endpoint will not get you the desired file.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_file(file_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str file_id: the id of the file (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_file_with_http_info(file_id, **kwargs)  # noqa: E501

    def get_file_with_http_info(self, file_id, **kwargs):  # noqa: E501
        """Download file  # noqa: E501

        Downloads file identified by given id.  Keep in mind to use GET /attachments/{attachmentId}/file instead of this endpoint when you want to get the file of an attachment.  A File and its id can be temporary so it's possible this endpoint will not get you the desired file.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_file_with_http_info(file_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str file_id: the id of the file (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(file, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'file_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_file" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'file_id' is set
        if self.api_client.client_side_validation and ('file_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['file_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `file_id` when calling `get_file`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'file_id' in local_var_params:
            path_params['fileId'] = local_var_params['file_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/files/{fileId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='file',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_file_info(self, file_id, **kwargs):  # noqa: E501
        """Get file information  # noqa: E501

        Returns information about the file identified by given id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_file_info(file_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str file_id: the id of the file (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ScopeImpl
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_file_info_with_http_info(file_id, **kwargs)  # noqa: E501

    def get_file_info_with_http_info(self, file_id, **kwargs):  # noqa: E501
        """Get file information  # noqa: E501

        Returns information about the file identified by given id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_file_info_with_http_info(file_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str file_id: the id of the file (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ScopeImpl, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'file_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_file_info" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'file_id' is set
        if self.api_client.client_side_validation and ('file_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['file_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `file_id` when calling `get_file_info`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'file_id' in local_var_params:
            path_params['fileId'] = local_var_params['file_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'bearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/files/{fileId}/info', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ScopeImpl',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import collibra_core
from collibra_core.api.assignments_api import AssignmentsApi  # noqa: E501
from collibra_core.rest import ApiException


class TestAssignmentsApi(unittest.TestCase):
    """AssignmentsApi unit test stubs"""

    def setUp(self):
        self.api = collibra_core.api.assignments_api.AssignmentsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_assignment(self):
        """Test case for add_assignment

        Adds a new Assignment.  # noqa: E501
        """
        pass

    def test_change_assignment(self):
        """Test case for change_assignment

        Changes the assignment with the information that is provided in the request.  # noqa: E501
        """
        pass

    def test_find_assignments_for_resource(self):
        """Test case for find_assignments_for_resource

        Find the assignments where a given resource is assigned.  # noqa: E501
        """
        pass

    def test_get_assignments_for_asset(self):
        """Test case for get_assignments_for_asset

        Returns the Assignment identified by the given Asset.  # noqa: E501
        """
        pass

    def test_get_assignments_for_asset_type(self):
        """Test case for get_assignments_for_asset_type

        Returns Assignments for given asset type id.  # noqa: E501
        """
        pass

    def test_get_available_asset_types_for_domain(self):
        """Test case for get_available_asset_types_for_domain

        Returns available asset types for domain identified by given id.  # noqa: E501
        """
        pass

    def test_get_available_attribute_types_for_asset(self):
        """Test case for get_available_attribute_types_for_asset

        Returns available attribute types for asset identified by given id.  # noqa: E501
        """
        pass

    def test_get_available_complex_relation_types_for_asset(self):
        """Test case for get_available_complex_relation_types_for_asset

        Returns the available ComplexRelationTypes for the Asset identified by the given id.  # noqa: E501
        """
        pass

    def test_get_available_relation_types_for_asset(self):
        """Test case for get_available_relation_types_for_asset

        Returns the available RelationTypes for the Asset identified by the given id.  # noqa: E501
        """
        pass

    def test_remove_assignment(self):
        """Test case for remove_assignment

        Removes the Assignment identified by the given id.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import collibra_core
from collibra_core.api.complex_relations_api import ComplexRelationsApi  # noqa: E501
from collibra_core.rest import ApiException


class TestComplexRelationsApi(unittest.TestCase):
    """ComplexRelationsApi unit test stubs"""

    def setUp(self):
        self.api = collibra_core.api.complex_relations_api.ComplexRelationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_complex_relation(self):
        """Test case for add_complex_relation

        Adds new complex relation.  # noqa: E501
        """
        pass

    def test_change_complex_relation(self):
        """Test case for change_complex_relation

        Change the complex relation with the information that is present in the request.  # noqa: E501
        """
        pass

    def test_export_to_csv(self):
        """Test case for export_to_csv

        Export complex relations of the given type to CSV.  # noqa: E501
        """
        pass

    def test_export_to_csv_as_string(self):
        """Test case for export_to_csv_as_string

        Export all complex relations of the given type to CSV as a String.  # noqa: E501
        """
        pass

    def test_export_to_csv_without_job(self):
        """Test case for export_to_csv_without_job

        Export all complex relations of the given type to a CSV file.  # noqa: E501
        """
        pass

    def test_export_to_excel(self):
        """Test case for export_to_excel

        Export complex relations of the given type to Excel.  # noqa: E501
        """
        pass

    def test_export_to_excel_without_job(self):
        """Test case for export_to_excel_without_job

        Export all complex relations of the given type to an Excel file.  # noqa: E501
        """
        pass

    def test_find_complex_relations(self):
        """Test case for find_complex_relations

        Returns complex relations matching the given search criteria.  # noqa: E501
        """
        pass

    def test_get_complex_relation(self):
        """Test case for get_complex_relation

        Returns a ComplexRelation identified by given id.  # noqa: E501
        """
        pass

    def test_remove_complex_relation(self):
        """Test case for remove_complex_relation

        Removes complex relation identified by given id.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import collibra_core
from collibra_core.api.workflow_instances_api import WorkflowInstancesApi  # noqa: E501
from collibra_core.rest import ApiException


class TestWorkflowInstancesApi(unittest.TestCase):
    """WorkflowInstancesApi unit test stubs"""

    def setUp(self):
        self.api = collibra_core.api.workflow_instances_api.WorkflowInstancesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_cancel_workflow_instances(self):
        """Test case for cancel_workflow_instances

        Cancel workflow instance.  # noqa: E501
        """
        pass

    def test_find_workflow_instances(self):
        """Test case for find_workflow_instances

        Find workflow instances.  # noqa: E501
        """
        pass

    def test_get_workflow_instance_diagram(self):
        """Test case for get_workflow_instance_diagram

        Returns the file representing the diagram of workflow instance identified by the given ID.  # noqa: E501
        """
        pass

    def test_message_event_received(self):
        """Test case for message_event_received

        Pass message event to workflow engine.  # noqa: E501
        """
        pass

    def test_start_workflow_instances(self):
        """Test case for start_workflow_instances

        Start workflow instances.  # noqa: E501
        """
        pass

    def test_start_workflow_instances_in_job(self):
        """Test case for start_workflow_instances_in_job

        Start workflow instances.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import collibra_core
from collibra_core.api.communities_api import CommunitiesApi  # noqa: E501
from collibra_core.rest import ApiException


class TestCommunitiesApi(unittest.TestCase):
    """CommunitiesApi unit test stubs"""

    def setUp(self):
        self.api = collibra_core.api.communities_api.CommunitiesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_communities(self):
        """Test case for add_communities

        Add multiple communities  # noqa: E501
        """
        pass

    def test_add_community(self):
        """Test case for add_community

        Add community  # noqa: E501
        """
        pass

    def test_change_communities(self):
        """Test case for change_communities

        Change multiple communities  # noqa: E501
        """
        pass

    def test_change_community(self):
        """Test case for change_community

        Change community  # noqa: E501
        """
        pass

    def test_change_to_root_community(self):
        """Test case for change_to_root_community

        Change to root community  # noqa: E501
        """
        pass

    def test_find_communities(self):
        """Test case for find_communities

        Find communities  # noqa: E501
        """
        pass

    def test_get_community(self):
        """Test case for get_community

        Get community  # noqa: E501
        """
        pass

    def test_get_community_breadcrumb(self):
        """Test case for get_community_breadcrumb

        Get community breadcrumb  # noqa: E501
        """
        pass

    def test_remove_communities(self):
        """Test case for remove_communities

        Remove multiple communities  # noqa: E501
        """
        pass

    def test_remove_communities_in_job(self):
        """Test case for remove_communities_in_job

        Remove multiple communities asynchronously  # noqa: E501
        """
        pass

    def test_remove_community(self):
        """Test case for remove_community

        Remove community  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from collibra_core.configuration import Configuration


class AddIssueRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'responsible_community_id': 'str',
        'name': 'str',
        'type_id': 'str',
        'description': 'str',
        'priority': 'str',
        'requester_id': 'str',
        'related_assets': 'list[RelatedAssetReference]',
        'category_ids': 'list[str]'
    }

    attribute_map = {
        'responsible_community_id': 'responsibleCommunityId',
        'name': 'name',
        'type_id': 'typeId',
        'description': 'description',
        'priority': 'priority',
        'requester_id': 'requesterId',
        'related_assets': 'relatedAssets',
        'category_ids': 'categoryIds'
    }

    def __init__(self, responsible_community_id=None, name=None, type_id=None, description=None, priority=None, requester_id=None, related_assets=None, category_ids=None, local_vars_configuration=None):  # noqa: E501
        """AddIssueRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._responsible_community_id = None
        self._name = None
        self._type_id = None
        self._description = None
        self._priority = None
        self._requester_id = None
        self._related_assets = None
        self._category_ids = None
        self.discriminator = None

        if responsible_community_id is not None:
            self.responsible_community_id = responsible_community_id
        self.name = name
        self.type_id = type_id
        self.description = description
        if priority is not None:
            self.priority = priority
        if requester_id is not None:
            self.requester_id = requester_id
        if related_assets is not None:
            self.related_assets = related_assets
        if category_ids is not None:
            self.category_ids = category_ids

    @property
    def responsible_community_id(self):
        """Gets the responsible_community_id of this AddIssueRequest.  # noqa: E501

        The ID of the community responsible for handling the issue.  # noqa: E501

        :return: The responsible_community_id of this AddIssueRequest.  # noqa: E501
        :rtype: str
        """
        return self._responsible_community_id

    @responsible_community_id.setter
    def responsible_community_id(self, responsible_community_id):
        """Sets the responsible_community_id of this AddIssueRequest.

        The ID of the community responsible for handling the issue.  # noqa: E501

        :param responsible_community_id: The responsible_community_id of this AddIssueRequest.  # noqa: E501
        :type: str
        """

        self._responsible_community_id = responsible_community_id

    @property
    def name(self):
        """Gets the name of this AddIssueRequest.  # noqa: E501

        The name of the subject for which the issue is being created.  # noqa: E501

        :return: The name of this AddIssueRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AddIssueRequest.

        The name of the subject for which the issue is being created.  # noqa: E501

        :param name: The name of this AddIssueRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def type_id(self):
        """Gets the type_id of this AddIssueRequest.  # noqa: E501

        The type ID of the issue to be created.  # noqa: E501

        :return: The type_id of this AddIssueRequest.  # noqa: E501
        :rtype: str
        """
        return self._type_id

    @type_id.setter
    def type_id(self, type_id):
        """Sets the type_id of this AddIssueRequest.

        The type ID of the issue to be created.  # noqa: E501

        :param type_id: The type_id of this AddIssueRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and type_id is None:  # noqa: E501
            raise ValueError("Invalid value for `type_id`, must not be `None`")  # noqa: E501

        self._type_id = type_id

    @property
    def description(self):
        """Gets the description of this AddIssueRequest.  # noqa: E501

        The description for the issue.  # noqa: E501

        :return: The description of this AddIssueRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this AddIssueRequest.

        The description for the issue.  # noqa: E501

        :param description: The description of this AddIssueRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and description is None:  # noqa: E501
            raise ValueError("Invalid value for `description`, must not be `None`")  # noqa: E501

        self._description = description

    @property
    def priority(self):
        """Gets the priority of this AddIssueRequest.  # noqa: E501

        The priority for the issue.  # noqa: E501

        :return: The priority of this AddIssueRequest.  # noqa: E501
        :rtype: str
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """Sets the priority of this AddIssueRequest.

        The priority for the issue.  # noqa: E501

        :param priority: The priority of this AddIssueRequest.  # noqa: E501
        :type: str
        """

        self._priority = priority

    @property
    def requester_id(self):
        """Gets the requester_id of this AddIssueRequest.  # noqa: E501

        The requester of the issue.  # noqa: E501

        :return: The requester_id of this AddIssueRequest.  # noqa: E501
        :rtype: str
        """
        return self._requester_id

    @requester_id.setter
    def requester_id(self, requester_id):
        """Sets the requester_id of this AddIssueRequest.

        The requester of the issue.  # noqa: E501

        :param requester_id: The requester_id of this AddIssueRequest.  # noqa: E501
        :type: str
        """

        self._requester_id = requester_id

    @property
    def related_assets(self):
        """Gets the related_assets of this AddIssueRequest.  # noqa: E501

        The list of assets which the issue is related to.  # noqa: E501

        :return: The related_assets of this AddIssueRequest.  # noqa: E501
        :rtype: list[RelatedAssetReference]
        """
        return self._related_assets

    @related_assets.setter
    def related_assets(self, related_assets):
        """Sets the related_assets of this AddIssueRequest.

        The list of assets which the issue is related to.  # noqa: E501

        :param related_assets: The related_assets of this AddIssueRequest.  # noqa: E501
        :type: list[RelatedAssetReference]
        """

        self._related_assets = related_assets

    @property
    def category_ids(self):
        """Gets the category_ids of this AddIssueRequest.  # noqa: E501

        The list of IDs of assets which represent categories for this issue. Each asset in this list should be of type Issue Category.  # noqa: E501

        :return: The category_ids of this AddIssueRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._category_ids

    @category_ids.setter
    def category_ids(self, category_ids):
        """Sets the category_ids of this AddIssueRequest.

        The list of IDs of assets which represent categories for this issue. Each asset in this list should be of type Issue Category.  # noqa: E501

        :param category_ids: The category_ids of this AddIssueRequest.  # noqa: E501
        :type: list[str]
        """

        self._category_ids = category_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddIssueRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AddIssueRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from collibra_core.configuration import Configuration


class AddScopeRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'name': 'str',
        'description': 'str',
        'domain_ids': 'list[str]',
        'community_ids': 'list[str]'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'description': 'description',
        'domain_ids': 'domainIds',
        'community_ids': 'communityIds'
    }

    def __init__(self, id=None, name=None, description=None, domain_ids=None, community_ids=None, local_vars_configuration=None):  # noqa: E501
        """AddScopeRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._description = None
        self._domain_ids = None
        self._community_ids = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.name = name
        if description is not None:
            self.description = description
        if domain_ids is not None:
            self.domain_ids = domain_ids
        if community_ids is not None:
            self.community_ids = community_ids

    @property
    def id(self):
        """Gets the id of this AddScopeRequest.  # noqa: E501

        The ID of the new scope. Should be unique within all scopes.<br/>It should have a format of universally unique identifier (UUID) and should not start with<br/><code>00000000-0000-0000-</code> which is a reserved prefix.  # noqa: E501

        :return: The id of this AddScopeRequest.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this AddScopeRequest.

        The ID of the new scope. Should be unique within all scopes.<br/>It should have a format of universally unique identifier (UUID) and should not start with<br/><code>00000000-0000-0000-</code> which is a reserved prefix.  # noqa: E501

        :param id: The id of this AddScopeRequest.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this AddScopeRequest.  # noqa: E501

        The name of the new scope  # noqa: E501

        :return: The name of this AddScopeRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AddScopeRequest.

        The name of the new scope  # noqa: E501

        :param name: The name of this AddScopeRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 255):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `255`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def description(self):
        """Gets the description of this AddScopeRequest.  # noqa: E501

        The description of the new scope  # noqa: E501

        :return: The description of this AddScopeRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this AddScopeRequest.

        The description of the new scope  # noqa: E501

        :param description: The description of this AddScopeRequest.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) > 255):
            raise ValueError("Invalid value for `description`, length must be less than or equal to `255`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) < 0):
            raise ValueError("Invalid value for `description`, length must be greater than or equal to `0`")  # noqa: E501

        self._description = description

    @property
    def domain_ids(self):
        """Gets the domain_ids of this AddScopeRequest.  # noqa: E501

        The list of IDs for domains assigned to the new scope  # noqa: E501

        :return: The domain_ids of this AddScopeRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._domain_ids

    @domain_ids.setter
    def domain_ids(self, domain_ids):
        """Sets the domain_ids of this AddScopeRequest.

        The list of IDs for domains assigned to the new scope  # noqa: E501

        :param domain_ids: The domain_ids of this AddScopeRequest.  # noqa: E501
        :type: list[str]
        """

        self._domain_ids = domain_ids

    @property
    def community_ids(self):
        """Gets the community_ids of this AddScopeRequest.  # noqa: E501

        The list of IDs for communities assigned to the new scope  # noqa: E501

        :return: The community_ids of this AddScopeRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._community_ids

    @community_ids.setter
    def community_ids(self, community_ids):
        """Sets the community_ids of this AddScopeRequest.

        The list of IDs for communities assigned to the new scope  # noqa: E501

        :param community_ids: The community_ids of this AddScopeRequest.  # noqa: E501
        :type: list[str]
        """

        self._community_ids = community_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddScopeRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AddScopeRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from collibra_core.configuration import Configuration


class AddAssetRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'display_name': 'str',
        'domain_id': 'str',
        'type_id': 'str',
        'id': 'str',
        'status_id': 'str',
        'excluded_from_auto_hyperlinking': 'bool'
    }

    attribute_map = {
        'name': 'name',
        'display_name': 'displayName',
        'domain_id': 'domainId',
        'type_id': 'typeId',
        'id': 'id',
        'status_id': 'statusId',
        'excluded_from_auto_hyperlinking': 'excludedFromAutoHyperlinking'
    }

    def __init__(self, name=None, display_name=None, domain_id=None, type_id=None, id=None, status_id=None, excluded_from_auto_hyperlinking=None, local_vars_configuration=None):  # noqa: E501
        """AddAssetRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._display_name = None
        self._domain_id = None
        self._type_id = None
        self._id = None
        self._status_id = None
        self._excluded_from_auto_hyperlinking = None
        self.discriminator = None

        self.name = name
        if display_name is not None:
            self.display_name = display_name
        self.domain_id = domain_id
        self.type_id = type_id
        if id is not None:
            self.id = id
        if status_id is not None:
            self.status_id = status_id
        if excluded_from_auto_hyperlinking is not None:
            self.excluded_from_auto_hyperlinking = excluded_from_auto_hyperlinking

    @property
    def name(self):
        """Gets the name of this AddAssetRequest.  # noqa: E501

        The full name of the new asset. Should be unique within the domain.  # noqa: E501

        :return: The name of this AddAssetRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AddAssetRequest.

        The full name of the new asset. Should be unique within the domain.  # noqa: E501

        :param name: The name of this AddAssetRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 2000):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `2000`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def display_name(self):
        """Gets the display_name of this AddAssetRequest.  # noqa: E501

        The display name of the new asset.  # noqa: E501

        :return: The display_name of this AddAssetRequest.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this AddAssetRequest.

        The display name of the new asset.  # noqa: E501

        :param display_name: The display_name of this AddAssetRequest.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                display_name is not None and len(display_name) > 2000):
            raise ValueError("Invalid value for `display_name`, length must be less than or equal to `2000`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                display_name is not None and len(display_name) < 1):
            raise ValueError("Invalid value for `display_name`, length must be greater than or equal to `1`")  # noqa: E501

        self._display_name = display_name

    @property
    def domain_id(self):
        """Gets the domain_id of this AddAssetRequest.  # noqa: E501

        The ID of the domain that the new asset should be added to.  # noqa: E501

        :return: The domain_id of this AddAssetRequest.  # noqa: E501
        :rtype: str
        """
        return self._domain_id

    @domain_id.setter
    def domain_id(self, domain_id):
        """Sets the domain_id of this AddAssetRequest.

        The ID of the domain that the new asset should be added to.  # noqa: E501

        :param domain_id: The domain_id of this AddAssetRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and domain_id is None:  # noqa: E501
            raise ValueError("Invalid value for `domain_id`, must not be `None`")  # noqa: E501

        self._domain_id = domain_id

    @property
    def type_id(self):
        """Gets the type_id of this AddAssetRequest.  # noqa: E501

        The ID of the asset type of the new asset.  # noqa: E501

        :return: The type_id of this AddAssetRequest.  # noqa: E501
        :rtype: str
        """
        return self._type_id

    @type_id.setter
    def type_id(self, type_id):
        """Sets the type_id of this AddAssetRequest.

        The ID of the asset type of the new asset.  # noqa: E501

        :param type_id: The type_id of this AddAssetRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and type_id is None:  # noqa: E501
            raise ValueError("Invalid value for `type_id`, must not be `None`")  # noqa: E501

        self._type_id = type_id

    @property
    def id(self):
        """Gets the id of this AddAssetRequest.  # noqa: E501

        The ID of the new asset. Should be unique within all assets.<br/>It should have a format of universally unique identifier (UUID) and should not start with <code>00000000-0000-0000-</code> which is a reserved prefix.  # noqa: E501

        :return: The id of this AddAssetRequest.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this AddAssetRequest.

        The ID of the new asset. Should be unique within all assets.<br/>It should have a format of universally unique identifier (UUID) and should not start with <code>00000000-0000-0000-</code> which is a reserved prefix.  # noqa: E501

        :param id: The id of this AddAssetRequest.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def status_id(self):
        """Gets the status_id of this AddAssetRequest.  # noqa: E501

        The ID of the status of the new asset.  # noqa: E501

        :return: The status_id of this AddAssetRequest.  # noqa: E501
        :rtype: str
        """
        return self._status_id

    @status_id.setter
    def status_id(self, status_id):
        """Sets the status_id of this AddAssetRequest.

        The ID of the status of the new asset.  # noqa: E501

        :param status_id: The status_id of this AddAssetRequest.  # noqa: E501
        :type: str
        """

        self._status_id = status_id

    @property
    def excluded_from_auto_hyperlinking(self):
        """Gets the excluded_from_auto_hyperlinking of this AddAssetRequest.  # noqa: E501

        Whether or not to exclude the new asset from auto hyperlinking.  # noqa: E501

        :return: The excluded_from_auto_hyperlinking of this AddAssetRequest.  # noqa: E501
        :rtype: bool
        """
        return self._excluded_from_auto_hyperlinking

    @excluded_from_auto_hyperlinking.setter
    def excluded_from_auto_hyperlinking(self, excluded_from_auto_hyperlinking):
        """Sets the excluded_from_auto_hyperlinking of this AddAssetRequest.

        Whether or not to exclude the new asset from auto hyperlinking.  # noqa: E501

        :param excluded_from_auto_hyperlinking: The excluded_from_auto_hyperlinking of this AddAssetRequest.  # noqa: E501
        :type: bool
        """

        self._excluded_from_auto_hyperlinking = excluded_from_auto_hyperlinking

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddAssetRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AddAssetRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import collibra_core
from collibra_core.api.asset_types_api import AssetTypesApi  # noqa: E501
from collibra_core.rest import ApiException


class TestAssetTypesApi(unittest.TestCase):
    """AssetTypesApi unit test stubs"""

    def setUp(self):
        self.api = collibra_core.api.asset_types_api.AssetTypesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_asset_type(self):
        """Test case for add_asset_type

        Add asset type  # noqa: E501
        """
        pass

    def test_add_asset_types(self):
        """Test case for add_asset_types

        Add multiple asset types  # noqa: E501
        """
        pass

    def test_change_asset_type(self):
        """Test case for change_asset_type

        Change asset type  # noqa: E501
        """
        pass

    def test_change_asset_types(self):
        """Test case for change_asset_types

        Change multiple asset types  # noqa: E501
        """
        pass

    def test_find_asset_types(self):
        """Test case for find_asset_types

        Find asset types matching criteria  # noqa: E501
        """
        pass

    def test_find_parent_types(self):
        """Test case for find_parent_types

        Find parent types  # noqa: E501
        """
        pass

    def test_find_sub_asset_types(self):
        """Test case for find_sub_asset_types

        Find asset subtypes  # noqa: E501
        """
        pass

    def test_get_asset_type(self):
        """Test case for get_asset_type

        Get asset type by ID  # noqa: E501
        """
        pass

    def test_remove_asset_type(self):
        """Test case for remove_asset_type

        Remove asset type by ID  # noqa: E501
        """
        pass

    def test_remove_asset_types(self):
        """Test case for remove_asset_types

        Remove multiple asset types  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Collibra Data Governance Center Core API

    <p>The Core REST API allows you to create your own integrations with Collibra Data Governance Center.</p><p><i>Create custom applications to help users get access to the right data.</i></p>  # noqa: E501

    The version of the OpenAPI document: 2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from collibra_core.configuration import Configuration


class ChangeWorkflowDefinitionRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'description': 'str',
        'configuration_variables': 'dict(str, str)',
        'start_events': 'list[str]',
        'business_item_resource_type': 'str',
        'exclusivity': 'str',
        'guest_user_accessible': 'bool',
        'registered_user_accessible': 'bool',
        'candidate_user_check_disabled': 'bool',
        'candidate_user_check_enabled': 'bool',
        'global_create': 'bool',
        'enable': 'bool',
        'start_label': 'str',
        'start_role_ids': 'list[str]',
        'stop_role_ids': 'list[str]',
        'reassign_role_ids': 'list[str]'
    }

    attribute_map = {
        'name': 'name',
        'description': 'description',
        'configuration_variables': 'configurationVariables',
        'start_events': 'startEvents',
        'business_item_resource_type': 'businessItemResourceType',
        'exclusivity': 'exclusivity',
        'guest_user_accessible': 'guestUserAccessible',
        'registered_user_accessible': 'registeredUserAccessible',
        'candidate_user_check_disabled': 'candidateUserCheckDisabled',
        'candidate_user_check_enabled': 'candidateUserCheckEnabled',
        'global_create': 'globalCreate',
        'enable': 'enable',
        'start_label': 'startLabel',
        'start_role_ids': 'startRoleIds',
        'stop_role_ids': 'stopRoleIds',
        'reassign_role_ids': 'reassignRoleIds'
    }

    def __init__(self, name=None, description=None, configuration_variables=None, start_events=None, business_item_resource_type=None, exclusivity=None, guest_user_accessible=None, registered_user_accessible=None, candidate_user_check_disabled=None, candidate_user_check_enabled=None, global_create=None, enable=None, start_label=None, start_role_ids=None, stop_role_ids=None, reassign_role_ids=None, local_vars_configuration=None):  # noqa: E501
        """ChangeWorkflowDefinitionRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._description = None
        self._configuration_variables = None
        self._start_events = None
        self._business_item_resource_type = None
        self._exclusivity = None
        self._guest_user_accessible = None
        self._registered_user_accessible = None
        self._candidate_user_check_disabled = None
        self._candidate_user_check_enabled = None
        self._global_create = None
        self._enable = None
        self._start_label = None
        self._start_role_ids = None
        self._stop_role_ids = None
        self._reassign_role_ids = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if configuration_variables is not None:
            self.configuration_variables = configuration_variables
        if start_events is not None:
            self.start_events = start_events
        if business_item_resource_type is not None:
            self.business_item_resource_type = business_item_resource_type
        if exclusivity is not None:
            self.exclusivity = exclusivity
        if guest_user_accessible is not None:
            self.guest_user_accessible = guest_user_accessible
        if registered_user_accessible is not None:
            self.registered_user_accessible = registered_user_accessible
        if candidate_user_check_disabled is not None:
            self.candidate_user_check_disabled = candidate_user_check_disabled
        if candidate_user_check_enabled is not None:
            self.candidate_user_check_enabled = candidate_user_check_enabled
        if global_create is not None:
            self.global_create = global_create
        if enable is not None:
            self.enable = enable
        if start_label is not None:
            self.start_label = start_label
        if start_role_ids is not None:
            self.start_role_ids = start_role_ids
        if stop_role_ids is not None:
            self.stop_role_ids = stop_role_ids
        if reassign_role_ids is not None:
            self.reassign_role_ids = reassign_role_ids

    @property
    def name(self):
        """Gets the name of this ChangeWorkflowDefinitionRequest.  # noqa: E501

        The name of the workflow definition.  # noqa: E501

        :return: The name of this ChangeWorkflowDefinitionRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ChangeWorkflowDefinitionRequest.

        The name of the workflow definition.  # noqa: E501

        :param name: The name of this ChangeWorkflowDefinitionRequest.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 2000):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `2000`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def description(self):
        """Gets the description of this ChangeWorkflowDefinitionRequest.  # noqa: E501

        The new description for the workflow definition.  # noqa: E501

        :return: The description of this ChangeWorkflowDefinitionRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ChangeWorkflowDefinitionRequest.

        The new description for the workflow definition.  # noqa: E501

        :param description: The description of this ChangeWorkflowDefinitionRequest.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def configuration_variables(self):
        """Gets the configuration_variables of this ChangeWorkflowDefinitionRequest.  # noqa: E501

        The configuration variables.  # noqa: E501

        :return: The configuration_variables of this ChangeWorkflowDefinitionRequest.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._configuration_variables

    @configuration_variables.setter
    def configuration_variables(self, configuration_variables):
        """Sets the configuration_variables of this ChangeWorkflowDefinitionRequest.

        The configuration variables.  # noqa: E501

        :param configuration_variables: The configuration_variables of this ChangeWorkflowDefinitionRequest.  # noqa: E501
        :type: dict(str, str)
        """

        self._configuration_variables = configuration_variables

    @property
    def start_events(self):
        """Gets the start_events of this ChangeWorkflowDefinitionRequest.  # noqa: E501

        The list of workflow start event types.  # noqa: E501

        :return: The start_events of this ChangeWorkflowDefinitionRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._start_events

    @start_events.setter
    def start_events(self, start_events):
        """Sets the start_events of this ChangeWorkflowDefinitionRequest.

        The list of workflow start event types.  # noqa: E501

        :param start_events: The start_events of this ChangeWorkflowDefinitionRequest.  # noqa: E501
        :type: list[str]
        """
        allowed_values = ["ASSET_ADDED", "ASSET_REMOVED", "ASSET_STATUS_CHANGED", "ASSET_DOMAIN_CHANGED", "ASSET_TYPE_CHANGED", "ASSET_ATTRIBUTE_CHANGED", "ASSET_NAME_CHANGED", "ASSET_DISPLAY_NAME_CHANGED", "ASSET_ATTRIBUTE_ADDED", "ASSET_ATTRIBUTE_REMOVED", "DOMAIN_ADDED", "DOMAIN_REMOVED", "ROLE_GRANTED", "ROLE_REVOKED", "WORKFLOW_STARTED", "WORKFLOW_CANCELED", "WORKLFLOW_ESCALATION", "WORKFLOW_TASK_COMPLETED", "USER_ADDED", "USER_REMOVED", "USER_DISABLED", "COMMENT_ADDED", "COMMENT_REMOVED", "COMMENT_CHANGED", "RELATION_ADDED_AND_ASSET_IS_SOURCE", "RELATION_REMOVED_AND_ASSET_WAS_SOURCE", "RELATION_ADDED_AND_ASSET_IS_TARGET", "RELATION_REMOVED_AND_ASSET_WAS_TARGET", "TAG_ASSIGN_CHANGED", "CLASSIFICATION_MATCH_ACCEPTED", "CLASSIFICATION_MATCH_REJECTED", "CLASSIFICATION_MATCH_ADDED", "CLASSIFICATION_MATCH_REMOVED", "CLASSIFICATION_MATCH_UPDATED", "DATABASE_REGISTRATION_COMPLETED", "DATABASE_REGISTRATION_FAILED"]  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                not set(start_events).issubset(set(allowed_values))):  # noqa: E501
            raise ValueError(
                "Invalid values for `start_events` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(start_events) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._start_events = start_events

    @property
    def business_item_resource_type(self):
        """Gets the business_item_resource_type of this ChangeWorkflowDefinitionRequest.  # noqa: E501

        The type of the business item corresponding to the workflow.  # noqa: E501

        :return: The business_item_resource_type of this ChangeWorkflowDefinitionRequest.  # noqa: E501
        :rtype: str
        """
        return self._business_item_resource_type

    @business_item_resource_type.setter
    def business_item_resource_type(self, business_item_resource_type):
        """Sets the business_item_resource_type of this ChangeWorkflowDefinitionRequest.

        The type of the business item corresponding to the workflow.  # noqa: E501

        :param business_item_resource_type: The business_item_resource_type of this ChangeWorkflowDefinitionRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["ASSET", "DOMAIN", "COMMUNITY", "GLOBAL"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and business_item_resource_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `business_item_resource_type` ({0}), must be one of {1}"  # noqa: E501
                .format(business_item_resource_type, allowed_values)
            )

        self._business_item_resource_type = business_item_resource_type

    @property
    def exclusivity(self):
        """Gets the exclusivity of this ChangeWorkflowDefinitionRequest.  # noqa: E501

        Defines the number of times a resource workflow is able to be start.  # noqa: E501

        :return: The exclusivity of this ChangeWorkflowDefinitionRequest.  # noqa: E501
        :rtype: str
        """
        return self._exclusivity

    @exclusivity.setter
    def exclusivity(self, exclusivity):
        """Sets the exclusivity of this ChangeWorkflowDefinitionRequest.

        Defines the number of times a resource workflow is able to be start.  # noqa: E501

        :param exclusivity: The exclusivity of this ChangeWorkflowDefinitionRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["RESOURCE_EXCLUSIVITY", "DEFINITION_EXCLUSIVITY", "UNCONSTRAINED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and exclusivity not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `exclusivity` ({0}), must be one of {1}"  # noqa: E501
                .format(exclusivity, allowed_values)
            )

        self._exclusivity = exclusivity

    @property
    def guest_user_accessible(self):
        """Gets the guest_user_accessible of this ChangeWorkflowDefinitionRequest.  # noqa: E501


        :return: The guest_user_accessible of this ChangeWorkflowDefinitionRequest.  # noqa: E501
        :rtype: bool
        """
        return self._guest_user_accessible

    @guest_user_accessible.setter
    def guest_user_accessible(self, guest_user_accessible):
        """Sets the guest_user_accessible of this ChangeWorkflowDefinitionRequest.


        :param guest_user_accessible: The guest_user_accessible of this ChangeWorkflowDefinitionRequest.  # noqa: E501
        :type: bool
        """

        self._guest_user_accessible = guest_user_accessible

    @property
    def registered_user_accessible(self):
        """Gets the registered_user_accessible of this ChangeWorkflowDefinitionRequest.  # noqa: E501

        Whether the workflow should be accessible by the registered user.  # noqa: E501

        :return: The registered_user_accessible of this ChangeWorkflowDefinitionRequest.  # noqa: E501
        :rtype: bool
        """
        return self._registered_user_accessible

    @registered_user_accessible.setter
    def registered_user_accessible(self, registered_user_accessible):
        """Sets the registered_user_accessible of this ChangeWorkflowDefinitionRequest.

        Whether the workflow should be accessible by the registered user.  # noqa: E501

        :param registered_user_accessible: The registered_user_accessible of this ChangeWorkflowDefinitionRequest.  # noqa: E501
        :type: bool
        """

        self._registered_user_accessible = registered_user_accessible

    @property
    def candidate_user_check_disabled(self):
        """Gets the candidate_user_check_disabled of this ChangeWorkflowDefinitionRequest.  # noqa: E501

        Whether the candidate user check for the workflow should be disabled.  # noqa: E501

        :return: The candidate_user_check_disabled of this ChangeWorkflowDefinitionRequest.  # noqa: E501
        :rtype: bool
        """
        return self._candidate_user_check_disabled

    @candidate_user_check_disabled.setter
    def candidate_user_check_disabled(self, candidate_user_check_disabled):
        """Sets the candidate_user_check_disabled of this ChangeWorkflowDefinitionRequest.

        Whether the candidate user check for the workflow should be disabled.  # noqa: E501

        :param candidate_user_check_disabled: The candidate_user_check_disabled of this ChangeWorkflowDefinitionRequest.  # noqa: E501
        :type: bool
        """

        self._candidate_user_check_disabled = candidate_user_check_disabled

    @property
    def candidate_user_check_enabled(self):
        """Gets the candidate_user_check_enabled of this ChangeWorkflowDefinitionRequest.  # noqa: E501

        Whether the candidate user check for the workflow should be enabled.  # noqa: E501

        :return: The candidate_user_check_enabled of this ChangeWorkflowDefinitionRequest.  # noqa: E501
        :rtype: bool
        """
        return self._candidate_user_check_enabled

    @candidate_user_check_enabled.setter
    def candidate_user_check_enabled(self, candidate_user_check_enabled):
        """Sets the candidate_user_check_enabled of this ChangeWorkflowDefinitionRequest.

        Whether the candidate user check for the workflow should be enabled.  # noqa: E501

        :param candidate_user_check_enabled: The candidate_user_check_enabled of this ChangeWorkflowDefinitionRequest.  # noqa: E501
        :type: bool
        """

        self._candidate_user_check_enabled = candidate_user_check_enabled

    @property
    def global_create(self):
        """Gets the global_create of this ChangeWorkflowDefinitionRequest.  # noqa: E501

        Whether the workflow is accessible from the global create menu.  # noqa: E501

        :return: The global_create of this ChangeWorkflowDefinitionRequest.  # noqa: E501
        :rtype: bool
        """
        return self._global_create

    @global_create.setter
    def global_create(self, global_create):
        """Sets the global_create of this ChangeWorkflowDefinitionRequest.

        Whether the workflow is accessible from the global create menu.  # noqa: E501

        :param global_create: The global_create of this ChangeWorkflowDefinitionRequest.  # noqa: E501
        :type: bool
        """

        self._global_create = global_create

    @property
    def enable(self):
        """Gets the enable of this ChangeWorkflowDefinitionRequest.  # noqa: E501

        Whether the workflow definition should be enabled.  # noqa: E501

        :return: The enable of this ChangeWorkflowDefinitionRequest.  # noqa: E501
        :rtype: bool
        """
        return self._enable

    @enable.setter
    def enable(self, enable):
        """Sets the enable of this ChangeWorkflowDefinitionRequest.

        Whether the workflow definition should be enabled.  # noqa: E501

        :param enable: The enable of this ChangeWorkflowDefinitionRequest.  # noqa: E501
        :type: bool
        """

        self._enable = enable

    @property
    def start_label(self):
        """Gets the start_label of this ChangeWorkflowDefinitionRequest.  # noqa: E501

        The start label of the workflow.  # noqa: E501

        :return: The start_label of this ChangeWorkflowDefinitionRequest.  # noqa: E501
        :rtype: str
        """
        return self._start_label

    @start_label.setter
    def start_label(self, start_label):
        """Sets the start_label of this ChangeWorkflowDefinitionRequest.

        The start label of the workflow.  # noqa: E501

        :param start_label: The start_label of this ChangeWorkflowDefinitionRequest.  # noqa: E501
        :type: str
        """

        self._start_label = start_label

    @property
    def start_role_ids(self):
        """Gets the start_role_ids of this ChangeWorkflowDefinitionRequest.  # noqa: E501

        The list of IDs identifying the roles allowing to start the workflow.  # noqa: E501

        :return: The start_role_ids of this ChangeWorkflowDefinitionRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._start_role_ids

    @start_role_ids.setter
    def start_role_ids(self, start_role_ids):
        """Sets the start_role_ids of this ChangeWorkflowDefinitionRequest.

        The list of IDs identifying the roles allowing to start the workflow.  # noqa: E501

        :param start_role_ids: The start_role_ids of this ChangeWorkflowDefinitionRequest.  # noqa: E501
        :type: list[str]
        """

        self._start_role_ids = start_role_ids

    @property
    def stop_role_ids(self):
        """Gets the stop_role_ids of this ChangeWorkflowDefinitionRequest.  # noqa: E501

        The list of IDs identifying the roles allowing to stop the workflow.  # noqa: E501

        :return: The stop_role_ids of this ChangeWorkflowDefinitionRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._stop_role_ids

    @stop_role_ids.setter
    def stop_role_ids(self, stop_role_ids):
        """Sets the stop_role_ids of this ChangeWorkflowDefinitionRequest.

        The list of IDs identifying the roles allowing to stop the workflow.  # noqa: E501

        :param stop_role_ids: The stop_role_ids of this ChangeWorkflowDefinitionRequest.  # noqa: E501
        :type: list[str]
        """

        self._stop_role_ids = stop_role_ids

    @property
    def reassign_role_ids(self):
        """Gets the reassign_role_ids of this ChangeWorkflowDefinitionRequest.  # noqa: E501

        The list of IDs identifying the roles allowing to reassign the workflow.  # noqa: E501

        :return: The reassign_role_ids of this ChangeWorkflowDefinitionRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._reassign_role_ids

    @reassign_role_ids.setter
    def reassign_role_ids(self, reassign_role_ids):
        """Sets the reassign_role_ids of this ChangeWorkflowDefinitionRequest.

        The list of IDs identifying the roles allowing to reassign the workflow.  # noqa: E501

        :param reassign_role_ids: The reassign_role_ids of this ChangeWorkflowDefinitionRequest.  # noqa: E501
        :type: list[str]
        """

        self._reassign_role_ids = reassign_role_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChangeWorkflowDefinitionRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ChangeWorkflowDefinitionRequest):
            return True

        return self.to_dict() != other.to_dict()
